from distutils.core import setup
setup(
    name='PyHostr',
    author='Sami Hindi',
    author_email='sami@samihindi.com',
    version='0.5',
    license='MIT',
    long_description=open('README.rst').read(),
    description='Python module for hosting your files, with routing.',
    url='https://github.com/FujiwaraChoki/PyHostr'
)
